@@ -10,7 +10,7 @@ test_that("Run jskm", {
        ystratalabs = c("Obs", "Lev", "Lev + 5FU"), ystrataname = "rx"), "gtable")
   expect_is(jskm(fit, timeby=500), "gg")
   expect_is(jskm(fit, timeby=500, main = "kaplan", xlabs = "time", ylabs = "Suvrival (%)", surv.scale = "percent"), "gg")
-  expect_is(jskm(fit, pval.size = 7, pval.coord = c(100, 0.2)), "gg")
+  expect_is(jskm(fit, pval.size = 7, pval.coord = c(100, 0.2),  pval.testname = T), "gg")
   expect_is(jskm(fit, timeby=500, ci = T), "gg")
   expect_is(jskm(fit, timeby=500, legend = F), "gg")
   expect_is(jskm(fit, timeby=500, cumhaz = T), "gg")
@@ -34,12 +34,12 @@ test_that("Run svyjskm", {
   s1 <- survey::svykm(Surv(time,status>0)~sex, design=dpbc, se = T)
   expect_is(svyjskm(s1, ci = T), "gg")
   expect_is(svyjskm(s1, ci = F, ylabs = "Suvrival (%)", surv.scale = "percent"), "gg")
-  #expect_is(svyjskm(s1, table = T, pval = T, design = dpbc), "gtable")
+  expect_is(svyjskm(s1, table = T, pval = T, design = dpbc), "gtable")
   expect_is(svyjskm(s1, ci = T, cumhaz = T), "gg")
   expect_is(svyjskm(s1, ci = F, cumhaz = T), "gg")
   s2 <- survey::svykm(Surv(time,status>0)~sex, design=dpbc, se = F)
   expect_is(svyjskm(s2, ci = F), "gg")
-  #expect_is(svyjskm(s2, design = dpbc, pval = T, pval.size = 7, pval.coord = c(100, 0.2)), "gg")
+  expect_is(svyjskm(s2, design = dpbc, pval = T, pval.size = 7, pval.coord = c(100, 0.2), pval.testname = T), "gg")
   #pv <- svyjskm(s2, pval = T, design = dpbc)
   #expect_is(pv, "gg")
   expect_error(svyjskm(s2, ci = T))
